pub struct ElectrumWalletFile { /* private fields */ }Expand description
Representation of an electrum wallet file. Has custom serialization and de-serialization routines to more accurately represent what we need, and the electrum wallet file format.
Implementations
Sourceimpl ElectrumWalletFile
impl ElectrumWalletFile
Sourcepub fn new(
keystores: &[Keystore],
min_signatures: u8,
) -> Result<Self, Electrum2DescriptorError>
pub fn new( keystores: &[Keystore], min_signatures: u8, ) -> Result<Self, Electrum2DescriptorError>
Construct a wallet
Sourcepub fn wallet_type(&self) -> &WalletType
pub fn wallet_type(&self) -> &WalletType
Getter for wallet_type
Sourcepub fn from_file(wallet_file: &Path) -> Result<Self, Electrum2DescriptorError>
pub fn from_file(wallet_file: &Path) -> Result<Self, Electrum2DescriptorError>
Parse an electrum wallet file
Sourcepub fn to_file(
&self,
wallet_file: &Path,
) -> Result<(), Electrum2DescriptorError>
pub fn to_file( &self, wallet_file: &Path, ) -> Result<(), Electrum2DescriptorError>
Write to an electrum wallet file
Sourcepub fn from_descriptor(desc: &str) -> Result<Self, Electrum2DescriptorError>
pub fn from_descriptor(desc: &str) -> Result<Self, Electrum2DescriptorError>
Construct from an output descriptor. Only the external descriptor is needed, the change descriptor is implied.
Sourcepub fn to_descriptors(&self) -> Result<Descriptors, Electrum2DescriptorError>
pub fn to_descriptors(&self) -> Result<Descriptors, Electrum2DescriptorError>
Generate output descriptors matching the electrum wallet